Welcome, AI Traineree!
======================

As you may have noticed, current version of the documentation is rather modest. True.
But be patient, young one, as this is only the beginning. Hopefully.

It is always a motivational boost and a driver to see that someone is using the project.
Feel free to let me know if you have any questions or anything, and I'll sure try to help.

.. toctree::
   :maxdepth: 2
   :caption: Current contents:

   Getting started <intro>
   examples
   agents
   multi_agent
   buffers
   policies
   networks
   environments
   tasks
   development


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
